//
// SydB☮x: seccomp and landlock based application sandbox with support for namespaces
// src/syd-tty.rs: Print the controlling terminal of the given process or the current process.
//
// Copyright (c) 2024 Ali Polatel <alip@chesswob.org>
//
// SPDX-License-Identifier: GPL-3.0-or-later

use std::{
    io::{stdout, Write},
    os::unix::ffi::OsStrExt,
    process::ExitCode,
};

use nix::{libc::pid_t, unistd::Pid};
use syd::proc::proc_tty;

fn main() -> ExitCode {
    match std::env::args().nth(1).map(|arg| arg.parse::<pid_t>()) {
        Some(Ok(pid)) => match proc_tty(Some(Pid::from_raw(pid))) {
            Ok(path) => {
                let path = path.as_os_str().as_bytes();
                #[allow(clippy::disallowed_methods)]
                stdout().write_all(path).expect("write_all");
            }
            Err(errno) => {
                eprintln!("syd-tty: {errno}");
                return ExitCode::from(errno as u8);
            }
        },
        None => match proc_tty(None) {
            Ok(path) => {
                let path = path.as_os_str().as_bytes();
                #[allow(clippy::disallowed_methods)]
                stdout().write_all(path).expect("write_all");
            }
            Err(errno) => {
                eprintln!("syd-tty: {errno}");
                return ExitCode::from(errno as u8);
            }
        },
        _ => {
            println!("Usage: syd-tty [PID]");
            println!("Print the controlling terminal of the given process or the current process.");
            return ExitCode::FAILURE;
        }
    }

    ExitCode::SUCCESS
}
